from flask import _app_ctx_stack

from pyArango.connection import Connection


class Arango(object):

    def __init__(self, app=None):
        self.app = app
        if app is not None:
            self.init_app(app)

    def init_app(self, app):
        self.app = app
        app.teardown_appcontext(self._teardown)

    def _teardown(self, exception):
        # pylint: disable=unused-argument,no-self-use
        ctx = _app_ctx_stack.top
        if ctx is not None:
            if hasattr(ctx, 'arango'):
                ctx.arango.session.close()
                del ctx.arango

    @property
    def connection(self):  # pylint: disable=no-self-use
        ctx = _app_ctx_stack.top
        if ctx is not None:
            if not hasattr(ctx, 'arango'):
                ctx.arango = Connection(self.app.config['ARANGO_URL'])
            return ctx.arango

    @property
    def db(self):  # pylint: disable=invalid-name
        return self.connection[self.app.config['ARANGO_DB']]

    @property
    def gdb(self):
        return self.db.graphs[self.app.config['ARANGO_GRAPH']]



"""
Flask-Arango
-------------

Flask extension that provides integration with the Arango graph database using
the pyArango library. Under initial development.

"""
from setuptools import setup


setup(
    name='Flask-Arango',
    version='0.1.1',
    url='https://github.com/grucin/flask-arango',
    license='Apache License, 2.0',
    author='Grzegorz Rucinski',
    author_email='grucin@gmail.com',
    description='Flask extension providing integration with Arango.',
    long_description=__doc__,
    py_modules=['flask_arango'],
    zip_safe=False,
    include_package_data=True,
    install_requires=[
        'Flask >= 0.10',
        'pyArango >= 1.0.3'
    ],
    classifiers=[
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)
